@@ -1,3 +1,95 @@
+#' histogram of returns
+#' 
+#' Create a histogram of returns, with optional curve fits for density and
+#' normal.  This is a wrapper function for \code{\link[graphics]{hist}}, see
+#' the help for that function for additional arguments you may wish to pass in.
+#' 
+#' The default for \code{breaks} is \code{"FD"}. Other names for which
+#' algorithms are supplied are \code{"Sturges"} (see
+#' \code{\link{nclass.Sturges}}), \code{"Scott"}, and \code{"FD"} /
+#' \code{"Freedman-Diaconis"} (with corresponding functions
+#' \code{\link{nclass.scott}} and \code{\link{nclass.FD}}).  Case is ignored
+#' and partial matching is used.  Alternatively, a function can be supplied
+#' which will compute the intended number of breaks as a function of \code{R}.
+#' 
+#' @param R an xts, vector, matrix, data frame, timeSeries or zoo object of
+#' asset returns
+#' @param breaks one of: \itemize{ \item a vector giving the breakpoints
+#' between histogram cells, \item a single number giving the number of cells
+#' for the histogram, \item a character string naming an algorithm to compute
+#' the number of cells (see \sQuote{Details}), \item a function to compute the
+#' number of cells.  } In the last three cases the number is a suggestion only.
+#' see \code{\link[graphics]{hist}} for details, default "FD"
+#' @param methods what to graph, one or more of: \describe{ \item{add.density}{
+#' to display the density plot} \item{add.normal}{ to display a fitted normal
+#' distibution line over the mean} \item{add.centered}{ to display a fitted
+#' normal line over zero} \item{add.rug}{ to display a rug of the observations}
+#' \item{add.risk}{ to display common risk metrics} \item{add.qqplot}{ to
+#' display a small qqplot in the upper corner of the histogram plot} }
+#' @param p confidence level for calculation, default p=.99
+#' @param probability logical; if TRUE, the histogram graphic is a
+#' representation of frequencies, the counts component of the result; if FALSE,
+#' probability densities, component density, are plotted (so that the histogram
+#' has a total area of one). Defaults to TRUE if and only if breaks are
+#' equidistant (and probability is not specified). see
+#' \code{\link[graphics]{hist}}
+#' @param show.outliers logical; if TRUE (the default), the histogram will show
+#' all of the data points.  If FALSE, it will show only the first through the
+#' fourth quartile and will exclude outliers.
+#' @param main set the chart title, same as in \code{\link{plot}}
+#' @param ylab set the y-axis label, same as in \code{\link{plot}}
+#' @param xlab set the x-axis label, same as in \code{\link{plot}}
+#' @param ylim set the y-axis limits, same as in \code{\link{plot}}
+#' @param border.col color to use for the border
+#' @param xlim set the x-axis limit, same as in \code{\link{plot}}
+#' @param lwd set the line width, same as in \code{\link{plot}}
+#' @param colorset color palette to use, set by default to rational choices
+#' @param element.color provides the color for drawing chart elements, such as
+#' the box lines, axis lines, etc. Default is "darkgray"
+#' @param note.lines draws a vertical line through the value given.
+#' @param note.labels adds a text label to vertical lines specified for
+#' note.lines.
+#' @param note.cex The magnification to be used for note line labels relative
+#' to the current setting of 'cex'.
+#' @param note.color specifies the color(s) of the vertical lines drawn.
+#' @param cex.legend The magnification to be used for sizing the legend
+#' relative to the current setting of 'cex'.
+#' @param cex.axis The magnification to be used for axis annotation relative to
+#' the current setting of 'cex', same as in \code{\link{plot}}.
+#' @param cex.lab The magnification to be used for x- and y-axis labels
+#' relative to the current setting of 'cex'.
+#' @param cex.main The magnification to be used for the main title relative to
+#' the current setting of 'cex'.
+#' @param xaxis if true, draws the x axis
+#' @param yaxis if true, draws the y axis
+#' @param \dots any other passthru parameters to \code{\link{plot}}
+#' @note Code inspired by a chart on: \cr
+#' \url{http://zoonek2.free.fr/UNIX/48_R/03.html}
+#' @author Peter Carl
+#' @seealso \code{\link[graphics]{hist}}
+#' @keywords ts multivariate distribution models hplot
+#' @examples
+#' 
+#'     data(edhec)
+#'     chart.Histogram(edhec[,'Equity Market Neutral',drop=FALSE])
+#' 
+#'     # version with more breaks and the standard close fit density distribution
+#'     chart.Histogram(edhec[,'Equity Market Neutral',drop=FALSE], breaks=40, methods = c("add.density", "add.rug") )
+#' 
+#'     chart.Histogram(edhec[,'Equity Market Neutral',drop=FALSE], methods = c( "add.density", "add.normal") )
+#' 
+#'     # version with just the histogram and normal distribution centered on 0
+#'     chart.Histogram(edhec[,'Equity Market Neutral',drop=FALSE], methods = c( "add.density", "add.centered") )
+#' 
+#'     # add a rug to the previous plot for more granularity on precisely where the distribution fell
+#'     chart.Histogram(edhec[,'Equity Market Neutral',drop=FALSE], methods = c( "add.centered", "add.density", "add.rug") )
+#' 
+#'     # now show a qqplot to give us another view on how normal the data are
+#'     chart.Histogram(edhec[,'Equity Market Neutral',drop=FALSE], methods = c( "add.centered", "add.density", "add.rug", "add.qqplot") )
+#' 
+#'     # add risk measure(s) to show where those are in relation to observed returns
+#'     chart.Histogram(edhec[,'Equity Market Neutral',drop=FALSE], methods = c("add.density", "add.centered", "add.rug", "add.risk") )
+#' 
 chart.Histogram <-
 function(R, breaks="FD", main = NULL, xlab = "Returns", ylab = "Frequency", methods = c("none","add.density", "add.normal", "add.centered", "add.cauchy", "add.sst", "add.rug", "add.risk", "add.qqplot"), show.outliers = TRUE, colorset = c("lightgray", "#00008F", "#005AFF", "#23FFDC", "#ECFF13", "#FF4A00", "#800000"), border.col = "white", lwd = 2, xlim = NULL, ylim = NULL, element.color="darkgray", note.lines = NULL, note.labels = NULL, note.cex = 0.7, note.color = "darkgray", probability = FALSE, p = 0.95, cex.axis = 0.8, cex.legend = 0.8, cex.lab = 1, cex.main = 1, xaxis=TRUE, yaxis=TRUE, ...)
 { # @author Peter Carl
@@ -34,7 +126,7 @@ function(R, breaks="FD", main = NULL, xlab = "Returns", ylab = "Frequency", meth
     if(show.outliers)
         rangedata = c(min(x),max(x))
     else
-        rangedata =  c(qnorm(0.001, mean(x), sd(x)), qnorm(0.999, mean(x), sd(x)))
+        rangedata =  c(qnorm(0.001, mean(x), sd.xts(x)), qnorm(0.999, mean(x), sd.xts(x)))
     if(!is.null(note.lines)) {
         rangedata = c(rangedata,note.lines)
     }
@@ -101,12 +193,12 @@ function(R, breaks="FD", main = NULL, xlab = "Returns", ylab = "Frequency", meth
                 probability = TRUE
             },
             add.normal = {
-                fitted.normal = dnorm(s, mean(x), sd(x))
+                fitted.normal = dnorm(s, mean(x), sd.xts(x))
                 yrange=c(yrange,max(fitted.normal))
                 probability = TRUE
             },
             add.centered = {
-                fitted.centered = dnorm(s, 0, sd(x))
+                fitted.centered = dnorm(s, 0, sd.xts(x))
                 yrange=c(yrange,max(fitted.centered))
                 probability = TRUE
             },
@@ -199,11 +291,11 @@ function(R, breaks="FD", main = NULL, xlab = "Returns", ylab = "Frequency", meth
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Histogram.R 1730 2010-08-03 19:31:06Z braverock $
+# $Id: chart.Histogram.R 1883 2012-03-25 00:59:31Z braverock $
 #
-###############################################################################
\ No newline at end of file
+###############################################################################
