@@ -1,3 +1,58 @@
+#' chart risk versus return over rolling time periods
+#' 
+#' A chart that shows rolling calculations of annualized return and annualized
+#' standard deviation have proceeded through time.  Lines and dots are darker
+#' for more recent time periods.
+#' 
+#' 
+#' @param R an xts, vector, matrix, data frame, timeSeries or zoo object of
+#' asset returns
+#' @param Rf risk free rate, in same period as your returns
+#' @param main set the chart title, same as in \code{plot}
+#' @param add.names plots the row name with the data point.  default TRUE. Can
+#' be removed by setting it to NULL
+#' @param xlab set the x-axis label, as in \code{\link{plot}}
+#' @param ylab set the y-axis label, as in \code{\link{plot}}
+#' @param add.sharpe this draws a Sharpe ratio line that indicates Sharpe ratio
+#' levels of \code{c(1,2,3)}.  Lines are drawn with a y-intercept of the risk
+#' free rate and the slope of the appropriate Sharpe ratio level.  Lines should
+#' be removed where not appropriate (e.g., sharpe.ratio = NULL).
+#' @param colorset color palette to use, set by default to rational choices
+#' @param symbolset from \code{pch} in \code{\link{plot}}, submit a set of
+#' symbols to be used in the same order as the data sets submitted
+#' @param cex.legend The magnification to be used for sizing the legend
+#' relative to the current setting of 'cex'.
+#' @param element.color provides the color for drawing chart elements, such as
+#' the box lines, axis lines, etc. Default is "darkgray"
+#' @param legend.loc places a legend into one of nine locations on the chart:
+#' bottomright, bottom, bottomleft, left, topleft, top, topright, right, or
+#' center.
+#' @param xlim set the x-axis limit, same as in \code{\link{plot}}
+#' @param ylim set the y-axis limit, same as in \code{\link{plot}}
+#' @param width number of periods to apply rolling calculations over, sometimes
+#' referred to as a 'window'
+#' @param stepsize the frequency with which to make the rolling calculation
+#' @param lty set the line type, same as in \code{\link{plot}}
+#' @param lwd set the line width, same as in \code{\link{plot}}
+#' @param cex.lab The magnification to be used for sizing the label relative to
+#' the current setting of 'cex', similar to \code{\link{plot}}.
+#' @param cex.main The magnification to be used for sizing the main chart
+#' relative to the current setting of 'cex', as in \code{\link{plot}}.
+#' @param cex.axis The magnification to be used for sizing the axis text
+#' relative to the current setting of 'cex', similar to \code{\link{plot}}.
+#' @param cex.text The magnification to be used for sizing the text relative to
+#' the current setting of 'cex', similar to \code{\link{plot}}.
+#' @param \dots any other passthru parameters
+#' @author Peter Carl
+#' @seealso \code{\link{chart.RiskReturnScatter}}
+#' @references ~put references to the literature/web site here ~
+#' @keywords ts
+#' @examples
+#' 
+#' data(managers)
+#' chart.SnailTrail(managers[,c("HAM2","SP500 TR"),drop=FALSE], width=36, stepsize=12, colorset=c('red','orange'),add.names="firstandlast", rf=.04/12, main="Trailing 36-month Performance Calc'd Every 12 Months")
+#' 
+#' 
 chart.SnailTrail <-
 function (R, Rf = 0, main = "Annualized Return and Risk", add.names = c("all", "lastonly", "firstandlast", "none"), xlab = "Annualized Risk", ylab = "Annualized Return", add.sharpe = c(1,2,3), colorset = 1:12, symbolset = 16, legend.loc = NULL, xlim = NULL, ylim = NULL, width = 12, stepsize = 12, lty=1, lwd=2, cex.axis=0.8, cex.main = 1, cex.lab = 1, cex.text = 0.8, cex.legend = 0.8, element.color="darkgray", ...)
 { # @author Peter Carl
@@ -92,7 +147,7 @@ function (R, Rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
 
         # colortrail = gray(0:(length(returns))/(length(returns)))
         colors = colorRamp(c(colorset[column],"white"))
-        colortrail = rgb(colors((0:maxrows)/maxrows),max=255)
+        colortrail = rgb(colors((0:maxrows)/maxrows),maxColorValue=255)
         n.rows = length(returns[,column])
         m.rows = length(na.omit(returns[,column]))
 
@@ -155,11 +210,11 @@ function (R, Rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.SnailTrail.R 1730 2010-08-03 19:31:06Z braverock $
+# $Id: chart.SnailTrail.R 1888 2012-03-25 14:35:48Z braverock $
 #
-###############################################################################
\ No newline at end of file
+###############################################################################
