@@ -1,3 +1,95 @@
+#' create a stacked bar plot
+#' 
+#' This creates a stacked column chart with time on the horizontal axis and
+#' values in categories.  This kind of chart is commonly used for showing
+#' portfolio 'weights' through time, although the function will plot any values
+#' by category.
+#' 
+#' This function is a wrapper for \code{\link{barplot}} but adds three
+#' additional capabilities.  First, it calculates and sets a bottom margin for
+#' long column names that are rotated vertically.  That doesn't always result
+#' in the prettiest chart, but it does ensure readable labels.
+#' 
+#' Second, it places a legend "under" the graph rather than within the bounds
+#' of the chart (which would obscure the data).  The legend is created from the
+#' column names.  The default is to create the legend when there's more than
+#' one row of data being presented.  If there is one row of data, the chart may
+#' be "unstacked" and the legend removed.
+#' 
+#' Third, it plots or stacks negative values from an origin of zero, similar to
+#' the behavior of \code{\link[lattice]{barchart}} from the 'lattice' package.
+#' 
+#' @param w a matrix, data frame or zoo object of values to be plotted.
+#' Rownames should contain dates or period labels; column names should indicate
+#' categories.  See examples for detail.
+#' @param colorset color palette to use, set by default to rational choices
+#' @param space the amount of space (as a fraction of the average bar width)
+#' left before each bar, as in \code{\link{barplot}}. Default is 0.2.
+#' @param cex.legend The magnification to be used for sizing the legend
+#' relative to the current setting of 'cex', similar to \code{\link{plot}}.
+#' @param cex.labels The magnification to be used for event line labels
+#' relative to the current setting of 'cex'.
+#' @param cex.lab The magnification to be used for x- and y-axis labels
+#' relative to the current setting of 'cex'.
+#' @param cex.main The magnification to be used for the chart title relative to
+#' the current setting of 'cex'.
+#' @param xaxis If true, draws the x axis
+#' @param ylab Set the y-axis label, same as in \code{\link{plot}}
+#' @param date.format Re-format the dates for the xaxis; the default is "%m/%y"
+#' @param major.ticks Should major tickmarks be drawn and labeled, default
+#' 'auto'
+#' @param minor.ticks Should minor tickmarks be drawn, default TRUE
+#' @param xaxis.labels Allows for non-date labeling of date axes, default is
+#' NULL
+#' @param cex.axis The magnification to be used for sizing the axis text
+#' relative to the current setting of 'cex', similar to \code{\link{plot}}.
+#' @param las sets the orientation of the axis labels, as described in
+#' \code{\link{par}}.  Defaults to '3'.
+#' @param legend.loc places a legend into a location on the chart similar to
+#' \code{\link{chart.TimeSeries}}. The default, "under," is the only location
+#' currently implemented for this chart.  Use 'NULL' to remove the legend.
+#' @param element.color provides the color for drawing less-important chart
+#' elements, such as the box lines, axis lines, etc.
+#' @param unstacked logical.  If set to 'TRUE' \emph{and} only one row of data
+#' is submitted in 'w', then the chart creates a normal column chart.  If more
+#' than one row is submitted, then this is ignored.  See examples below.
+#' @param xlab the x-axis label, which defaults to 'NULL'.
+#' @param ylim set the y-axis limit, same as in \code{\link{plot}}
+#' @param \dots arguments to be passed to \code{\link{barplot}}.
+#' @note The 'w' attribute is so named because this is a popular way to show
+#' portfolio weights through time.  That being said, this function isn't
+#' limited to any particular values and doesn't provide any normalization, so
+#' that the chart can be used more generally.
+#' 
+#' The principal drawback of stacked column charts is that it is very difficult
+#' for the reader to judge size of 2nd, 3rd, etc., data series because they do
+#' not have common baseline.  Another is that with a large number of series,
+#' the colors may be difficult to discern.  As alternatives, Cleveland
+#' advocates the use of trellis like displays, and Tufte advocates the use of
+#' small multiple charts.
+#' @author Peter Carl
+#' @seealso \code{\link{barplot}}, \code{\link{par}}
+#' @references Cleveland, W.S. (1994), The Elements of Graphing Data, Summit,
+#' NJ: Hobart Press.
+#' 
+#' Tufte, Edward R. (2001) The Visual Display of Quantitative Information, 2nd
+#' edition. The Graphics Press, Cheshire, Connecticut. See
+#' http://www.edwardtufte.com for this and other references.
+#' @keywords ts multivariate hplot
+#' @examples
+#' 
+#' data(weights)
+#' head(weights)
+#' 
+#' # With the legend "under" the chart
+#' chart.StackedBar(weights, date.format="%Y", cex.legend = 0.7, colorset=rainbow12equal)
+#' 
+#' # Without the legend
+#' chart.StackedBar(weights, colorset=rainbow12equal, legend.loc=NULL)
+#' 
+#' # for one row of data, use 'unstacked' for a better chart
+#' chart.StackedBar(weights[1,,drop=FALSE], unstacked=TRUE, las=3)
+#' 
 chart.StackedBar <- 
 function (w, colorset = NULL, space = 0.2, cex.axis=0.8, cex.legend = 0.8, cex.lab = 1, cex.labels = 0.8, cex.main = 1, xaxis=TRUE, legend.loc="under",  element.color = "darkgray", unstacked = TRUE, xlab="Date", ylab="Value", ylim=NULL, date.format = "%b %y", major.ticks='auto', minor.ticks=TRUE, las = 0, xaxis.labels = NULL, ... ) 
 {
@@ -42,7 +134,7 @@ function (w, colorset = NULL, space = 0.2, cex.axis=0.8, cex.legend = 0.8, cex.l
     if(!is.null(legend.loc) ){
         if(legend.loc =="under") {# put the legend under the chart
             op <- par(no.readonly=TRUE)
-            layout(rbind(1,2), height=c(6,1), width=1)
+            layout(rbind(1,2), heights=c(6,1), widths=1)
             par(mar=c(3,4,4,2)+.1) # set the margins of the first panel
 # c(bottom, left, top, right)
         }
@@ -72,7 +164,7 @@ function (w, colorset = NULL, space = 0.2, cex.axis=0.8, cex.legend = 0.8, cex.l
     }
 
     barplot(t(positives), col=colorset, space=space, axisnames = FALSE, axes = FALSE, ylim=ylim, ...)
-    barplot(t(negatives), add=TRUE , col=colorset, space=space, las = las, xlab = xlab, cex.names = cex.names, axes = FALSE, axisnames = FALSE, ylim=ylim, ...)
+    barplot(t(negatives), add=TRUE , col=colorset, space=space, las = las, xlab = xlab, cex.names = cex.lab, axes = FALSE, axisnames = FALSE, ylim=ylim, ...)
     axis(2, col = element.color, las = las, cex.axis = cex.axis)
     title(ylab = ylab, cex = cex.lab)
     if (xaxis) {
@@ -142,7 +234,7 @@ function (w, colorset = NULL, space = 0.2, cex.axis=0.8, cex.legend = 0.8, cex.l
         if(!is.null(legend.loc) ){
             if(legend.loc =="under") {# put the legend under the chart
                 op <- par(no.readonly=TRUE)
-                layout(rbind(1,2), height=c(6,1), width=1)
+                layout(rbind(1,2), heights=c(6,1), widths=1)
                 par(mar=c(3,4,4,2)+.1) # set the margins of the first panel
             }
         }
@@ -168,7 +260,7 @@ function (w, colorset = NULL, space = 0.2, cex.axis=0.8, cex.legend = 0.8, cex.l
         }
 
         barplot(t(positives), col=colorset, space=space, axisnames = FALSE, axes = FALSE, ylim=ylim, xlab="", ...)
-        barplot(t(negatives), add=TRUE , col=colorset, space=space, las = las, xlab = "", cex.names = cex.names, axes = FALSE, axisnames = FALSE, ylim=ylim, ...)
+        barplot(t(negatives), add=TRUE , col=colorset, space=space, las = las, xlab = "", cex.names = cex.lab, axes = FALSE, axisnames = FALSE, ylim=ylim, ...)
         axis(2, col = element.color, las = las, cex.axis = cex.axis)
         title(ylab = ylab, cex = cex.lab)
         if (xaxis) {
@@ -200,11 +292,11 @@ function (w, colorset = NULL, space = 0.2, cex.axis=0.8, cex.legend = 0.8, cex.l
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.StackedBar.R 1735 2010-08-04 00:05:46Z peter_carl $
+# $Id: chart.StackedBar.R 1889 2012-03-29 22:36:47Z braverock $
 #
-###############################################################################
\ No newline at end of file
+###############################################################################
