@@ -1,3 +1,48 @@
+#' show the sensitivity of Value-at-Risk or Expected Shortfall estimates
+#' 
+#' Creates a chart of Value-at-Risk and/or Expected Shortfall estimates by
+#' confidence interval for multiple methods.
+#' 
+#' This chart shows estimated VaR along a series of confidence intervals for
+#' selected calculation methods.  Useful for comparing a method to the
+#' historical VaR calculation.
+#' 
+#' @param R an xts, vector, matrix, data frame, timeSeries or zoo object of
+#' asset returns
+#' @param methods one or more calculation methods indicated "GaussianVaR",
+#' "ModifiedVaR", "HistoricalVaR", "GaussianES", "ModifiedES", "HistoricalES".
+#' See \code{\link{VaR}} or \code{\link{ES}} for more detail.
+#' @param clean method for data cleaning through \code{\link{Return.clean}}.
+#' Current options are "none" or "boudt" or "geltner".
+#' @param elementcolor the color used to draw chart elements. The default is
+#' "darkgray"
+#' @param reference.grid if true, draws a grid aligned with the points on the x
+#' and y axes
+#' @param ylab set the y-axis label, same as in \code{\link{plot}}
+#' @param xlab set the x-axis label, same as in \code{\link{plot}}
+#' @param type set the chart type, same as in \code{\link{plot}}
+#' @param lty set the line type, same as in \code{\link{plot}}
+#' @param lwd set the line width, same as in \code{\link{plot}}
+#' @param colorset color palette to use, set by default to rational choices
+#' @param pch symbols to use, see also \code{\link{plot}}
+#' @param legend.loc places a legend into one of nine locations on the chart:
+#' bottomright, bottom, bottomleft, left, topleft, top, topright, right, or
+#' center.
+#' @param cex.legend The magnification to be used for sizing the legend
+#' relative to the current setting of 'cex'.
+#' @param main set the chart title, same as in \code{\link{plot}}
+#' @param \dots any other passthru parameters
+#' @author Peter Carl
+#' @seealso \code{\link{VaR}} \cr \code{\link{ES}}
+#' @references Boudt, K., Peterson, B. G., Croux, C., 2008. Estimation and
+#' Decomposition of Downside Risk for Portfolios with Non-Normal Returns.
+#' Journal of Risk, forthcoming.
+#' @keywords ts multivariate distribution
+#' @examples
+#' 
+#' data(managers)
+#' chart.VaRSensitivity(managers[,1,drop=FALSE], methods=c("HistoricalVaR", "ModifiedVaR", "GaussianVaR"), colorset=bluefocus, lwd=2)
+#' 
 chart.VaRSensitivity <-
 function (R, methods = c("GaussianVaR", "ModifiedVaR", "HistoricalVaR","GaussianES", "ModifiedES", "HistoricalES"), clean=c("none", "boudt", "geltner"), elementcolor="darkgray", reference.grid=TRUE, xlab = "Confidence Level", ylab="Value at Risk", type = "l", lty = c(1,2,4), lwd = 1, colorset = (1:12), pch = (1:12), legend.loc = "bottomleft", cex.legend = 0.8, main=NULL,...)
 { # @author Peter Carl
@@ -78,7 +123,7 @@ function (R, methods = c("GaussianVaR", "ModifiedVaR", "HistoricalVaR","Gaussian
     }
 
     # draw x-axis
-    axis(1, lab=p, at=p, col = elementcolor) # at= 1/(1:length(p))
+    axis(1, labels=p, at=p, col = elementcolor) # at= 1/(1:length(p))
     title(xlab = xlab)
 
     # set up y-axis
@@ -101,11 +146,11 @@ function (R, methods = c("GaussianVaR", "ModifiedVaR", "HistoricalVaR","Gaussian
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.VaRSensitivity.R 1730 2010-08-03 19:31:06Z braverock $
+# $Id: chart.VaRSensitivity.R 1888 2012-03-25 14:35:48Z braverock $
 #
-###############################################################################
\ No newline at end of file
+###############################################################################
