@@ -1,3 +1,53 @@
+#' Create combined wealth index, period performance, and drawdown chart
+#' 
+#' For a set of returns, create a wealth index chart, bars for per-period
+#' performance, and underwater chart for drawdown.
+#' 
+#' 
+#' @param R an xts, vector, matrix, data frame, timeSeries or zoo object of
+#' asset returns
+#' @param Rf risk free rate, in same period as your returns
+#' @param p confidence level for calculation, default p=.95
+#' @param main set the chart title, as in \code{plot}
+#' @param geometric generate geometric (TRUE) or simple (FALSE) returns,
+#' default TRUE
+#' @param methods Used to select the risk parameter of trailing \code{width}
+#' returns to use in the \code{\link{chart.BarVaR}} panel: May be any of:
+#' \itemize{ \item None - does not add a line, \item ModifiedVaR - uses
+#' Cornish-Fisher modified VaR, \item GaussianVaR - uses traditional Value at
+#' Risk, \item HistoricalVaR - calculates historical Value at Risk, \item
+#' ModifiedES - uses Cornish-Fisher modified Expected Shortfall, \item
+#' GaussianES - uses traditional Expected Shortfall, \item HistoricalES -
+#' calculates historical Expected Shortfall, \item StdDev - per-period standard
+#' deviation }
+#' @param begin Align shorter series to: \itemize{ \item first - prior value of
+#' the first column given for the reference or longer series or, \item axis -
+#' the initial value (1 or zero) of the axis.  } passthru to
+#' \code{\link{chart.CumReturns}}
+#' @param event.labels TRUE/FALSE whether or not to display lines and labels
+#' for historical market shock events
+#' @param wealth.index if \code{wealth.index} is \code{TRUE}, shows the "value
+#' of $1", starting the cumulation of returns at 1 rather than zero
+#' @param width number of periods to apply rolling function window over
+#' @param gap numeric number of periods from start of series to use to train
+#' risk calculation
+#' @param ylog TRUE/FALSE set the y-axis to logarithmic scale, similar to
+#' \code{\link{plot}}, default FALSE
+#' @param legend.loc sets the legend location in the top chart.  Can be set to
+#' NULL or nine locations on the chart: bottomright, bottom, bottomleft, left,
+#' topleft, top, topright, right, or center.
+#' @param \dots any other passthru parameters
+#' @note Most inputs are the same as "\code{\link{plot}}" and are principally
+#' included so that some sensible defaults could be set.
+#' @author Peter Carl
+#' @seealso \code{\link{chart.CumReturns}} \cr \code{\link{chart.BarVaR}} \cr
+#' \code{\link{chart.Drawdown}}
+#' @keywords ts multivariate distribution models hplot
+#' @examples
+#' 
+#' data(edhec)
+#' charts.PerformanceSummary(edhec[,c(1,13)])
+#' 
 charts.PerformanceSummary <-
 function (R, Rf = 0, main = NULL, geometric=TRUE, methods = "none", width = 0, event.labels = NULL, ylog = FALSE, wealth.index = FALSE, gap = 12, begin=c("first","axis"), legend.loc="topleft", p=0.95,...)
 { # @author Peter Carl
@@ -57,7 +107,7 @@ function (R, Rf = 0, main = NULL, geometric=TRUE, methods = "none", width = 0, e
 
     # First, we lay out the graphic as a three row, one column format
 #    plot.new()
-    layout(matrix(c(1,2,3)),height=c(2,1,1.3),width=1)
+    layout(matrix(c(1,2,3)),heights=c(2,1,1.3),widths=1)
     # to see the resulting layout, use layout.show(3)
 
     # mar: a numerical vector of the form c(bottom, left, top, right) which
@@ -99,11 +149,11 @@ function (R, Rf = 0, main = NULL, geometric=TRUE, methods = "none", width = 0, e
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: charts.PerformanceSummary.R 1730 2010-08-03 19:31:06Z braverock $
+# $Id: charts.PerformanceSummary.R 1888 2012-03-25 14:35:48Z braverock $
 #
-###############################################################################
\ No newline at end of file
+###############################################################################
